==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebTreeItemComponentEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTreeItemDescriptionMetadata } from "./WebTreeItemDescriptionMetadata";
import { WebTreeItemComponentEventArgsDescription } from "./WebTreeItemComponentEventArgsDescription";
/**
 * @hidden
 */
export let WebTreeItemComponentEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebTreeItemComponentEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebTreeItemComponentEventArgsDescriptionMetadata.a == null) {
                WebTreeItemComponentEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebTreeItemComponentEventArgsDescriptionMetadata.c(WebTreeItemComponentEventArgsDescriptionMetadata.a);
            }
            if (a.j(WebTreeItemComponentEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebTreeItemComponentEventArgsDescriptionMetadata.a);
            WebTreeItemDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:TreeItemComponentEventArgs");
            a.item("Detail", "ExportedType:WebTreeItem");
        }
        static d(a) {
            WebTreeItemComponentEventArgsDescriptionMetadata.b(a);
            a.aa("WebTreeItemComponentEventArgs", () => new WebTreeItemComponentEventArgsDescription());
            a.z("WebTreeItemComponentEventArgs", WebTreeItemComponentEventArgsDescriptionMetadata.a);
        }
    }
    WebTreeItemComponentEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebTreeItemComponentEventArgsDescriptionMetadata, 'WebTreeItemComponentEventArgsDescriptionMetadata');
    WebTreeItemComponentEventArgsDescriptionMetadata.a = null;
    return WebTreeItemComponentEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebTreeItemComponentEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTreeItemDescriptionMetadata } from "./WebTreeItemDescriptionMetadata";
import { WebTreeItemComponentEventArgsDescription } from "./WebTreeItemComponentEventArgsDescription";
/**
 * @hidden
 */
export let WebTreeItemComponentEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebTreeItemComponentEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebTreeItemComponentEventArgsDescriptionMetadata.a == null) {
                WebTreeItemComponentEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebTreeItemComponentEventArgsDescriptionMetadata.c(WebTreeItemComponentEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebTreeItemComponentEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebTreeItemComponentEventArgsDescriptionMetadata.a);
            WebTreeItemDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:TreeItemComponentEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Detail", "ExportedType:WebTreeItem");
        }
        static d(a) {
            WebTreeItemComponentEventArgsDescriptionMetadata.b(a);
            a.ac("WebTreeItemComponentEventArgs", () => new WebTreeItemComponentEventArgsDescription());
            a.ab("WebTreeItemComponentEventArgs", WebTreeItemComponentEventArgsDescriptionMetadata.a);
        }
    }
    WebTreeItemComponentEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebTreeItemComponentEventArgsDescriptionMetadata, 'WebTreeItemComponentEventArgsDescriptionMetadata');
    WebTreeItemComponentEventArgsDescriptionMetadata.a = null;
    return WebTreeItemComponentEventArgsDescriptionMetadata;
})();
